@@ -20,19 +20,17 @@ List stabit2Sel1(Rcpp::List Yr, Rcpp::List Xmatchr, Rcpp::List Cr,
   Rcpp::List Dr, Rcpp::List dr, Rcpp::List Mr, Rcpp::List Hr, 
   arma::colvec nCollegesr, arma::colvec nStudentsr, Rcpp::List XXmatchr,
   Rcpp::List CCr, Rcpp::List SSr, Rcpp::List CCmatchr, Rcpp::List SSmatchr,
-  Rcpp::List Lr, Rcpp::List studentIdsr, Rcpp::List collegeIdr, arma::colvec nEquilibsr,
-  Rcpp::List sopt2equr, Rcpp::List equ2soptr, Rcpp::List copt2equr, Rcpp::List equ2coptr, arma::colvec coptidr,
+  Rcpp::List Lr, Rcpp::List studentIdsr, Rcpp::List collegeIdr, 
   int n, int N, bool binary, int niter, int T, int censored, int thin, bool display_progress = true) {
   
   // ---------------------------------------------
   // Independent variables
   // ---------------------------------------------
-    
-  arma::field<arma::mat> Xmatch(T), C(T), Cmatch(T), S(T), Smatch(T), XXmatch(T), CC(T), SS(T), CCmatch(T), SSmatch(T), collegeId(T); 
-  arma::field<arma::uvec> L(T), d(T);
-  arma::field<arma::umat> M(T), studentIds(N), sopt2equ(T), equ2sopt(T), copt2equ(T), equ2copt(T);
-  arma::field<arma::colvec> D(T); 
-  arma::field<arma::cube> H(T);
+  
+  arma::field<arma::mat> Xmatch(T), C(T), Cmatch(T), H(T), S(T), Smatch(T), XXmatch(T), CC(T), SS(T), CCmatch(T), SSmatch(T); 
+  arma::field<arma::uvec> L(T), studentIds(N), d(T);
+  arma::field<arma::umat> M(T);
+  arma::field<arma::colvec> D(T), collegeId(T); 
 
   for(int i=0; i<T; i++){
     Xmatch(i) = Rcpp::as<arma::mat>(Xmatchr[i]);  
@@ -43,28 +41,22 @@ List stabit2Sel1(Rcpp::List Yr, Rcpp::List Xmatchr, Rcpp::List Cr,
     D(i) = Rcpp::as<arma::colvec>(Dr[i]); 
     d(i) = Rcpp::as<arma::uvec>(dr[i]);  // uvec is used for logical indexing
     M(i) = Rcpp::as<arma::umat>(Mr[i]);  // umat is used for logical indexing
-    H(i) = Rcpp::as<arma::cube>(Hr[i]);  
+    H(i) = Rcpp::as<arma::mat>(Hr[i]);  
     XXmatch(i) = Rcpp::as<arma::mat>(XXmatchr[i]); 
     CC(i) = Rcpp::as<arma::mat>(CCr[i]);  
     SS(i) = Rcpp::as<arma::mat>(SSr[i]); 
     CCmatch(i) = Rcpp::as<arma::mat>(CCmatchr[i]); 
     SSmatch(i) = Rcpp::as<arma::mat>(SSmatchr[i]); 
     L(i) = Rcpp::as<arma::uvec>(Lr[i]);  // uvec is used for logical indexing
-    collegeId(i) = Rcpp::as<arma::mat>(collegeIdr[i]); 
-    sopt2equ(i) = Rcpp::as<arma::umat>(sopt2equr[i]);
-    equ2sopt(i) = Rcpp::as<arma::umat>(equ2soptr[i]);
-    copt2equ(i) = Rcpp::as<arma::umat>(copt2equr[i]);
-    equ2copt(i) = Rcpp::as<arma::umat>(equ2coptr[i]);
+    collegeId(i) = Rcpp::as<arma::colvec>(collegeIdr[i]);
   }    
   
   for(int i=0; i<N; i++){
-    studentIds(i) = Rcpp::as<arma::umat>(studentIdsr[i]);  // umat is used for logical indexing
+    studentIds(i) = Rcpp::as<arma::uvec>(studentIdsr[i]);  // umat is used for logical indexing
   }
   
   arma::colvec nColleges = nCollegesr;
   arma::colvec nStudents = nStudentsr;
-  arma::colvec nEquilibs = nEquilibsr;
-  arma::colvec coptid = coptidr;
   
   // ---------------------------------------------
   // Outcome variables.
@@ -243,110 +235,42 @@ List stabit2Sel1(Rcpp::List Yr, Rcpp::List Xmatchr, Rcpp::List Cr,
           
           // --- Draw of u_j,i: student j's valuation over college i (truncated by equilibrium bounds) ---
           
-          for(int k=0; k < nEquilibs(t); k++){
+          if(H(t)(i,j) == 0){  // non-equilibrium matches
+            
+            // Eqn (A4)
+            // if student's valuation is higher than minimum of college's students (so college prefers student)
+            if( Vs(t)(M(t)(i,j)) > arma::min(Vs(t)(M(t)(iuvec, studentIds(L(t)(i)) ))) ){  
+              // then college's valuation has to be lower than that of student's equilibrium college
+              Vcupperbar = std::min( Vcupperbar, Vc(t)(M(t)(collegeId(t)(j),j)) ); 
+            }
+            
+          } else{  // equilibrium matches
+            
+            for( int iprime=0; iprime < nColleges(t); iprime++ ){
+              // convert int iprime to uvec iprimeuvec for non-contiguous indexing in umatrix M
+              ivec(0) = iprime;  
+              arma::uvec iprimeuvec = arma::conv_to<arma::uvec>::from(ivec); 
+              
+              // if student not matched to college iprime
+              if( H(t)(iprime,j) == 0 ){  
+                // Eqn (A6)
+                // if student's valuation is higher than minimum of imprime's students (so college prefers student)
+                if( Vs(t)(M(t)(iprime,j)) > arma::min(Vs(t)(M(t)(iprimeuvec,studentIds(L(t)(iprime))))) ){  
+                  // Eqn (A11) = Eqn (A15_b), term 1
+                  // then student must value college i higher than iprime
+                  Vclowerbar = std::max( Vclowerbar, std::max(Vclowerbar,Vc(t)(M(t)(iprime,j))) ); 
+                }  
+              }     
+            }
+            
+          } // non-equilibrium vs. equilibrium 
           
-            if(H(t)(i,j,k) == 0){  // non-equilibrium matches
-              
-              // Eqn (A4)
-              // if student's valuation is higher than minimum of college's students (so college prefers student)
-              if( Vs(t)(M(t)(i,j)) > arma::min(Vs(t)(M(t)(iuvec, studentIds(L(t)(i)).col(k) ))) ){  
-                // then college's valuation has to be lower than that of student's equilibrium college
-                Vcupperbar = std::min( Vcupperbar, Vc(t)(M(t)(collegeId(t)(j,k),j)) ); 
-              }
-              
-            } else{  // equilibrium matches
-              
-              if(k == 0){ // student-optimal equilibrium
-                
-                for( int iprime=0; iprime < nColleges(t); iprime++ ){
-                  // convert int iprime to uvec iprimeuvec for non-contiguous indexing in umatrix M
-                  ivec(0) = iprime;  
-                  arma::uvec iprimeuvec = arma::conv_to<arma::uvec>::from(ivec); 
-              
-                  // if student not matched to college iprime
-                  if( H(t)(iprime,j,k) == 0 ){  
-                    // Eqn (A6)
-                    // if student's valuation is higher than minimum of imprime's students (so college prefers student)
-                    if( Vs(t)(M(t)(iprime,j)) > arma::min(Vs(t)(M(t)(iprimeuvec,studentIds(L(t)(iprime)).col(k)))) ){  
-                      // Eqn (A5), term 1
-                      // then student must value college i higher than iprime
-                      Vclowerbar = std::max( Vclowerbar, std::max(Vclowerbar,Vc(t)(M(t)(iprime,j))) ); 
-                    }  
-                  }     
-                } 
-                
-                for(int l=1; l < nEquilibs(t); l++){
-                  if( collegeId(t)(j,l) != collegeId(t)(j,0) ){ // only if mu'(j) != mu^s(j)
-                    // Eqn (A5), term 2
-                    Vclowerbar = std::max( Vclowerbar, Vc(t)(M(t)(collegeId(t)(j,l),j)) );
-                  }
-                }
-                
-              } else if(k == coptid[t]){ // college-optimal equilibrium
-                
-                for( int iprime=0; iprime < nColleges(t); iprime++ ){
-                  // convert int iprime to uvec iprimeuvec for non-contiguous indexing in umatrix M
-                  ivec(0) = iprime;  
-                  arma::uvec iprimeuvec = arma::conv_to<arma::uvec>::from(ivec); 
-                  
-                  // if student not matched to college iprime
-                  if( H(t)(iprime,j,k) == 0 ){  
-                    // Eqn (A6)
-                    // if student's valuation is higher than minimum of imprime's students (so college prefers student)
-                    if( Vs(t)(M(t)(iprime,j)) > arma::min(Vs(t)(M(t)(iprimeuvec,studentIds(L(t)(iprime)).col(k)))) ){  
-                      // Eqn (A10_b)
-                      // then student must value college i higher than iprime
-                      Vclowerbar = std::max( Vclowerbar, std::max(Vclowerbar,Vc(t)(M(t)(iprime,j))) ); 
-                    }  
-                  }     
-                } 
-                
-                for(int l=0; l < nEquilibs(t); l++){
-                  if( (collegeId(t)(j,l) != collegeId(t)(j,k)) ){ // only if mu'(j) != mu^s(j)
-                    // Eqn (A11_b)
-                    Vcupperbar = std::min( Vcupperbar, Vc(t)(M(t)(collegeId(t)(j,l),j)) );
-                  }
-                }
-
-              } else{ // other equilibrium
-                
-                for( int iprime=0; iprime < nColleges(t); iprime++ ){
-                  // convert int iprime to uvec iprimeuvec for non-contiguous indexing in umatrix M
-                  ivec(0) = iprime;  
-                  arma::uvec iprimeuvec = arma::conv_to<arma::uvec>::from(ivec); 
-                
-                  // if student not matched to college iprime
-                  if( H(t)(iprime,j,k) == 0 ){  
-                    // Eqn (A6)
-                    // if student's valuation is higher than minimum of imprime's students (so college prefers student)
-                    if( Vs(t)(M(t)(iprime,j)) > arma::min(Vs(t)(M(t)(iprimeuvec,studentIds(L(t)(iprime)).col(k)))) ){  
-                      // Eqn (A11) = Eqn (A15_b), term 1
-                      // then student must value college i higher than iprime
-                      Vclowerbar = std::max( Vclowerbar, std::max(Vclowerbar,Vc(t)(M(t)(iprime,j))) ); 
-                    }  
-                  }     
-                }
-                
-                if( collegeId(t)(j,k) != collegeId(t)(j,coptid[t]) ){ // only if mu'(j) != mu^s(j)
-                  // Eqn (A15_b), term 2
-                  Vclowerbar = std::max( Vclowerbar, Vc(t)(M(t)(collegeId(t)(j,coptid[t]),j)) );
-                }
-                
-                if( collegeId(t)(j,k) != collegeId(t)(j,0) ){ // only if mu'(j) != mu^s(j)
-                  // Eqn (A12) = Eqn (A16)
-                  Vcupperbar = std::min( Vcupperbar, Vc(t)(M(t)(collegeId(t)(j,0),j)) );
-                }
-                
-              } // student-optimal vs. other equilibrium         
-            } // non-equilibrium vs. equilibrium 
-          } // k = nEquilibs
-          
-          if(H(t)(i,j,0) == 0){ // non-equilibrium matches
+          if(H(t)(i,j) == 0){ // non-equilibrium matches
             
             Vhat = arma::as_scalar( C(t).row(M(t)(i,j))*beta ); 
             Vc(t)(M(t)(i,j)) = truncn2(Vhat, 1.0, Vclowerbar, Vcupperbar); // mu, sigma, lower, upper
                       
-          } else{
+          } else{ // equilibrium matches
             
             if((Vclowerbar != 0) | (Vcupperbar != 0)){
             
@@ -360,93 +284,33 @@ List stabit2Sel1(Rcpp::List Yr, Rcpp::List Xmatchr, Rcpp::List Cr,
           
           // --- Draw of u_i,j: college i's valuation over student j (truncated by equilibrium bounds) ---
           
-          for(int k=0; k < nEquilibs(t); k++){
+          if(H(t)(i,j) == 0){  // non-equilibrium matches
             
-            if(H(t)(i,j,k) == 0){  // non-equilibrium matches
-              
-              // Eqn (A3)            
-              // if student prefers college to current match
-              if( Vc(t)(M(t)(i,j)) > Vc(t)(M(t)(collegeId(t)(j,k),j)) ){ 
-                // then students' valuation has to be lower than that of worst student attending the college
-                Vsupperbar = std::min( Vsupperbar, arma::min(Vs(t)(M(t)( iuvec,studentIds(L(t)(i)).col(k) ))) ); 
-              }
-              
-            } else{  // equilibrium matches
-              
-              if(k==0){ // student-optimal equilibrium
-                
-                for( int jprime=0; jprime < nStudents(t); jprime++ ){             
-                  // if college not matched to student jprime
-                  if( H(t)(i,jprime,k)==0 ){  
-                    // Eqn (A9)
-                    // but student jprime values i over his equilibrium school
-                    if( Vc(t)(M(t)(i,jprime)) > Vc(t)(M(t)(collegeId(t)(jprime,k),jprime)) ){ 
-                      // Eqn (A7)
-                      // then school must value student j higher than jprime  
-                      Vslowerbar = std::max( Vslowerbar, Vs(t)(M(t)(i,jprime)) );
-                    } 
-                  } 
-                }
+            // Eqn (A3)            
+            // if student prefers college to current match
+            if( Vc(t)(M(t)(i,j)) > Vc(t)(M(t)(collegeId(t)(j),j)) ){ 
+              // then students' valuation has to be lower than that of worst student attending the college
+              Vsupperbar = std::min( Vsupperbar, arma::min(Vs(t)(M(t)( iuvec,studentIds(L(t)(i)) ))) ); 
+            }
+            
+          } else{  // equilibrium matches
+            
+            for( int jprime=0; jprime < nStudents(t); jprime++ ){             
+              // if college not matched to student jprime
+              if( H(t)(i,jprime)==0 ){  
+                // Eqn (A9)
+                // but student jprime values i over his equilibrium school
+                if( Vc(t)(M(t)(i,jprime)) > Vc(t)(M(t)(collegeId(t)(jprime),jprime)) ){ 
+                  // Eqn (A10), term 1
+                  // then school must value student j higher than jprime  
+                  Vslowerbar = std::max( Vslowerbar, Vs(t)(M(t)(i,jprime)) );
+                } 
+              } 
+            }
+            
+          } // non-equilibrium vs. equilibrium 
 
-                for(int l=1; l < nEquilibs(t); l++){
-                  if( j != sopt2equ(t)(j,l) ){ // only if mu^s(i) != mu'(i)
-                    // Eqn (A8)
-                    Vsupperbar = std::min( Vsupperbar, Vs(t)(M(t)(i,sopt2equ(t)(j,l))) );
-                  }
-                }
-                
-              } else if(k == coptid[t]){ // college-optimal equilibrium
-
-                for( int jprime=0; jprime < nStudents(t); jprime++ ){             
-                  // if college not matched to student jprime
-                  if( H(t)(i,jprime,k)==0 ){  
-                    // Eqn (A9)
-                    // but student jprime values i over his equilibrium school
-                    if( Vc(t)(M(t)(i,jprime)) > Vc(t)(M(t)(collegeId(t)(jprime,k),jprime)) ){ 
-                      // Eqn (A12_b), term 1
-                      // then school must value student j higher than jprime  
-                      Vslowerbar = std::max( Vslowerbar, Vs(t)(M(t)(i,jprime)) );
-                    } 
-                  } 
-                }
-                
-                for(int l=0; l < nEquilibs(t); l++){ 
-                  if( (j != copt2equ(t)(j,l)) & (l != k) ){ // only if mu^s(i) != mu'(i)
-                    // Eqn (A12_b), term 2
-                    Vslowerbar = std::max( Vslowerbar, Vs(t)(M(t)(i,copt2equ(t)(j,l))) );
-                  }
-                }
-                
-              } else{ // other equilibrium
-                
-                for( int jprime=0; jprime < nStudents(t); jprime++ ){             
-                  // if college not matched to student jprime
-                  if( H(t)(i,jprime,k)==0 ){  
-                    // Eqn (A9)
-                    // but student jprime values i over his equilibrium school
-                    if( Vc(t)(M(t)(i,jprime)) > Vc(t)(M(t)(collegeId(t)(jprime,k),jprime)) ){ 
-                      // Eqn (A10), term 1
-                      // then school must value student j higher than jprime  
-                      Vslowerbar = std::max( Vslowerbar, Vs(t)(M(t)(i,jprime)) );
-                    } 
-                  } 
-                }
-
-                if( j != equ2sopt(t)(j,k) ){ // only if mu'(i) != mu^s(i)
-                  // Eqn (A10), term 2
-                  Vslowerbar = std::max( Vslowerbar, Vs(t)(M(t)(i,equ2sopt(t)(j,k))) );
-                }
-                
-                if( j != equ2copt(t)(j,k) ){ // only if mu'(i) != mu^s(i)
-                  // Eqn (A14_b)
-                  Vsupperbar = std::min( Vsupperbar, Vs(t)(M(t)(i,equ2copt(t)(j,k))) );
-                }
-                
-              } // student-optimal vs. other equilibrium         
-            } // non-equilibrium vs. equilibrium 
-          } // k = nEquilibs
-          
-          if(H(t)(i,j,0) == 0){ // non-equilibrium matches
+          if(H(t)(i,j) == 0){ // non-equilibrium matches
             
             Vhat = arma::as_scalar( S(t).row(M(t)(i,j))*gamma ); 
             Vs(t)(M(t)(i,j)) = truncn2(Vhat, 1.0, Vslowerbar, Vsupperbar); // mu, sigma, lower, upper
